@@ -3,10 +3,10 @@ import io
 import os
 from urllib.parse import urlparse
 
-from flask import abort, send_file
+from flask import abort, send_file, request
 from flask_restful import Resource
 
-from .preview import generate_preview
+from httpdbg.webapp.preview import generate_preview
 
 from httpdbg.hook import HTTPRecords
 
@@ -112,13 +112,22 @@ class RequestList(Resource):
     def get(self):
         global httpdebugk7
 
+        if request.args.get("id") == httpdebugk7.id:
+            httpdebugk7.requests_already_loaded = int(
+                request.args.get("requests_already_loaded", 0)
+            )
+        else:
+            httpdebugk7.requests_already_loaded = 0
+
         k7 = {"id": httpdebugk7.id, "requests": {}}
         for id, req in httpdebugk7.requests.items():
 
             k7["requests"][id] = {
                 "id": req.id,
                 "unread": req.unread,
-                "url": req.request.url,
+                "url": req.url,
+                "netloc": req.netloc,
+                "urlext": req.urlext,
                 "status_code": req.status_code,
                 "reason": req.reason,
                 "verb": req.request.method,
